BINTEST
===
管理智能外呼所有的测试脚本

快速开始
---
如何构建、安装、运行

测试
---
如何执行自动化测试

如何贡献
---
贡献patch流程及质量要求

版本信息
---
版本信息请参考[CHANGELOG.md][changelog]

维护者
---
### owners
* zhangjiabin01(zhangjiabin01@baidu.com)

### committers
* zhangjiabin01(zhangjiabin01@baidu.com)

讨论
---
百度Hi交流群：群号


[changelog]: http://icode.baidu.com/repos/baidu/kefu-qa/aiob-utils/blob/master:CHANGELOG.md
